/***********************************************************************************************************************
 *
 * blueBill Mobile - open source birdwatching
 * ==========================================
 *
 * Copyright (C) 2009, 2010 by Tidalwave s.a.s. (http://www.tidalwave.it)
 * http://bluebill.tidalwave.it/mobile/
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * $Id: ObservationItem.java,v ecc110bc8552 2010/05/29 12:34:54 fabrizio $
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.observation;

import javax.annotation.Nonnull;
import java.io.Serializable;
import org.openide.util.Lookup;
import it.tidalwave.util.As;

/*******************************************************************************
 *
 * Represents a single item of an observation, targetting an {@link Observable}
 * with a {@link Cardinality}. It is also possible to attach a free text note.
 *
 * @author  Fabrizio Giudici
 * @version $Id: ObservationItem.java,v ecc110bc8552 2010/05/29 12:34:54 fabrizio $
 *
 ******************************************************************************/
public interface ObservationItem extends Lookup.Provider, As, Serializable
  {
    /***************************************************************************
     *
     * Returns the {@link Observable} that is the target of this
     * {@code ObservationItem}.
     *
     * @return  the {@code Observable}
     *
     **************************************************************************/
    @Nonnull
    public Observable getObservable();

    /***************************************************************************
     *
     * Returns the {@link Cardinality} of this {@code ObservationItem}.
     *
     * @return  the {@code Cardinality}
     *
     **************************************************************************/
    @Nonnull
    public Cardinality getCardinality();

    /***************************************************************************
     *
     * Returns the {@link Observation} that contains this {@code ObservationItem}.
     *
     * @return  the {@code Cardinality}
     *
     **************************************************************************/
    @Nonnull
    public Observation getObservation();
  }
